@@ -1,12 +1,12 @@
 // SPDX-License-Identifier: Apache-2.0
 // 
-// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 Conrad Sanderson (https://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
-// http://www.apache.org/licenses/LICENSE-2.0
+// https://www.apache.org/licenses/LICENSE-2.0
 // 
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,14 +23,14 @@
 //! Eigenvalues of real/complex symmetric/hermitian matrix X
 template<typename T1>
 inline
-typename enable_if2< is_supported_blas_type<typename T1::elem_type>::value, bool >::result
+typename enable_if2< is_blas_type<typename T1::elem_type>::value, bool >::result
 eig_sym
   (
          Col<typename T1::pod_type>&     eigval,
   const Base<typename T1::elem_type,T1>& X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
@@ -41,7 +41,7 @@ eig_sym
   if(status == false)
     {
     eigval.soft_reset();
-    arma_debug_warn_level(3, "eig_sym(): decomposition failed");
+    arma_warn(3, "eig_sym(): decomposition failed");
     }
   
   return status;
@@ -53,13 +53,13 @@ eig_sym
 template<typename T1>
 arma_warn_unused
 inline
-typename enable_if2< is_supported_blas_type<typename T1::elem_type>::value, Col<typename T1::pod_type> >::result
+typename enable_if2< is_blas_type<typename T1::elem_type>::value, Col<typename T1::pod_type> >::result
 eig_sym
   (
   const Base<typename T1::elem_type,T1>& X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   typedef typename T1::pod_type   T;
@@ -93,26 +93,34 @@ eig_sym_helper
   const char*                                   caller_sig
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  // if(auxlib::rudimentary_sym_check(X) == false)
-  //   {
-  //   if(is_cx<eT>::no )  { arma_debug_warn_level(1, caller_sig, ": given matrix is not symmetric"); }
-  //   if(is_cx<eT>::yes)  { arma_debug_warn_level(1, caller_sig, ": given matrix is not hermitian"); }
-  //   return false;
-  //   }
-  
-  if((arma_config::debug) && (auxlib::rudimentary_sym_check(X) == false))
+  if((arma_config::check_conform) && (auxlib::rudimentary_sym_check(X) == false))
     {
-    if(is_cx<eT>::no )  { arma_debug_warn_level(1, caller_sig, ": given matrix is not symmetric"); }
-    if(is_cx<eT>::yes)  { arma_debug_warn_level(1, caller_sig, ": given matrix is not hermitian"); }
+    if(is_cx<eT>::no )  { arma_warn(1, caller_sig, ": given matrix is not symmetric"); }
+    if(is_cx<eT>::yes)  { arma_warn(1, caller_sig, ": given matrix is not hermitian"); }
     }
   
   bool status = false;
   
-  if(method_sig == 'd') { status = auxlib::eig_sym_dc(eigval, eigvec, X); }
+  if(method_sig == 'd')
+    {
+    const bool allow_dc = (sizeof(blas_int) >= std::size_t(8)) ? true : (X.n_rows <= uword(32000));
+    
+    if(allow_dc)
+      {
+      status = auxlib::eig_sym_dc(eigval, eigvec, X);
+      }
+    else
+      {
+      arma_warn(3, caller_sig, ": matrix size too large for divide-and-conquer algorithm; using standard algorithm instead");
+      }
+    }
   
-  if(status == false)   { status = auxlib::eig_sym(eigval, eigvec, X);    }
+  if(status == false)
+    {
+    status = auxlib::eig_sym(eigval, eigvec, X);
+    }
   
   return status;
   }
@@ -122,7 +130,7 @@ eig_sym_helper
 //! Eigenvalues and eigenvectors of real/complex symmetric/hermitian matrix X
 template<typename T1> 
 inline
-typename enable_if2< is_supported_blas_type<typename T1::elem_type>::value, bool >::result
+typename enable_if2< is_blas_type<typename T1::elem_type>::value, bool >::result
 eig_sym
   (
          Col<typename T1::pod_type>&     eigval,
@@ -131,14 +139,14 @@ eig_sym
   const char* method =                   "dc"
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
   const char sig = (method != nullptr) ? method[0] : char(0);
   
-  arma_debug_check( ((sig != 's') && (sig != 'd')),         "eig_sym(): unknown method specified"                             );
-  arma_debug_check( void_ptr(&eigval) == void_ptr(&eigvec), "eig_sym(): parameter 'eigval' is an alias of parameter 'eigvec'" );
+  arma_conform_check( ((sig != 's') && (sig != 'd')),         "eig_sym(): unknown method specified"                             );
+  arma_conform_check( void_ptr(&eigval) == void_ptr(&eigvec), "eig_sym(): parameter 'eigval' is an alias of parameter 'eigvec'" );
   
   const quasi_unwrap<T1> U(expr.get_ref());
   
@@ -153,7 +161,7 @@ eig_sym
     {
     eigval.soft_reset();
     eigvec.soft_reset();
-    arma_debug_warn_level(3, "eig_sym(): decomposition failed");
+    arma_warn(3, "eig_sym(): decomposition failed");
     }
   else
     {
