@@ -1,10 +1,12 @@
-// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// SPDX-License-Identifier: Apache-2.0
+// 
+// Copyright 2008-2016 Conrad Sanderson (https://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
-// http://www.apache.org/licenses/LICENSE-2.0
+// https://www.apache.org/licenses/LICENSE-2.0
 // 
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,7 +23,7 @@
 
 template<typename T1>
 arma_warn_unused
-arma_inline
+inline
 typename
 enable_if2
   <
@@ -33,7 +35,7 @@ sort
   const T1& X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return Op<T1, op_sort_vec>(X, 0, 0);
   }
@@ -42,7 +44,7 @@ sort
 
 template<typename T1>
 arma_warn_unused
-arma_inline
+inline
 typename
 enable_if2
   <
@@ -54,7 +56,7 @@ sort
   const T1& X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return Op<T1, op_sort>(X, 0, 0);
   }
@@ -76,11 +78,11 @@ sort
   const T2*   sort_direction
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const char sig = (sort_direction != nullptr) ? sort_direction[0] : char(0);
   
-  arma_debug_check( (sig != 'a') && (sig != 'd'), "sort(): unknown sort direction");
+  arma_conform_check( (sig != 'a') && (sig != 'd'), "sort(): unknown sort direction" );
   
   const uword sort_type = (sig == 'a') ? 0 : 1;
   
@@ -104,11 +106,11 @@ sort
   const T2*   sort_direction
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const char sig = (sort_direction != nullptr) ? sort_direction[0] : char(0);
   
-  arma_debug_check( (sig != 'a') && (sig != 'd'), "sort(): unknown sort direction");
+  arma_conform_check( (sig != 'a') && (sig != 'd'), "sort(): unknown sort direction" );
   
   const uword sort_type = (sig == 'a') ? 0 : 1;
   
@@ -133,11 +135,11 @@ sort
   const uword dim
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const char sig = (sort_direction != nullptr) ? sort_direction[0] : char(0);
   
-  arma_debug_check( (sig != 'a') && (sig != 'd'), "sort(): unknown sort direction");
+  arma_conform_check( (sig != 'a') && (sig != 'd'), "sort(): unknown sort direction" );
   
   const uword sort_type = (sig == 'a') ? 0 : 1;
   
