@@ -1,12 +1,12 @@
 // SPDX-License-Identifier: Apache-2.0
 // 
-// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 Conrad Sanderson (https://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
-// http://www.apache.org/licenses/LICENSE-2.0
+// https://www.apache.org/licenses/LICENSE-2.0
 // 
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
@@ -185,7 +185,7 @@ op_inv_gen_full::apply_direct(Mat<typename T1::elem_type>& out, const Base<typen
   
   if(is_op_diagmat<T1>::value || out.is_diagmat())
     {
-    arma_debug_print("op_inv_gen_full: detected diagonal matrix");
+    arma_debug_print("op_inv_gen_full: diag optimisation");
     
     eT* colmem = out.memptr();
     
@@ -216,28 +216,16 @@ op_inv_gen_full::apply_direct(Mat<typename T1::elem_type>& out, const Base<typen
   
   if(is_triu_expr || is_tril_expr || is_triu_mat || is_tril_mat)
     {
+    arma_debug_print("op_inv_gen_full: tri optimisation");
+    
     return auxlib::inv_tr(out, ((is_triu_expr || is_triu_mat) ? uword(0) : uword(1)));
     }
   
-  const bool try_sympd = arma_config::optimise_sym && sym_helper::guess_sympd(out);
-  
-  if(try_sympd)
+  if( (arma_config::optimise_sym) && ( is_sym_expr<T1>::eval(expr.get_ref()) || sym_helper::is_approx_sym(out, uword(100)) ) )
     {
-    arma_debug_print("op_inv_gen_full: attempting sympd optimisation");
+    arma_debug_print("op_inv_gen_full: symmetric/hermitian optimisation");
     
-    Mat<eT> tmp = out;
-    
-    bool sympd_state = false;
-    
-    const bool status = auxlib::inv_sympd(tmp, sympd_state);
-    
-    if(status)  { out.steal_mem(tmp); return true; }
-    
-    if((status == false) && (sympd_state == true))  { return false; }
-    
-    arma_debug_print("op_inv_gen_full: sympd optimisation failed");
-    
-    // fallthrough if optimisation failed
+    return auxlib::inv_sym(out);
     }
   
   return auxlib::inv(out);
@@ -348,7 +336,7 @@ op_inv_gen_rcond::apply_direct(Mat<typename T1::elem_type>& out, op_inv_gen_stat
   
   if(is_op_diagmat<T1>::value || out.is_diagmat())
     {
-    arma_debug_print("op_inv_gen_rcond: detected diagonal matrix");
+    arma_debug_print("op_inv_gen_rcond: diag optimisation");
     
     out_state.is_diag = true;
     
@@ -394,30 +382,18 @@ op_inv_gen_rcond::apply_direct(Mat<typename T1::elem_type>& out, op_inv_gen_stat
   
   if(is_triu_expr || is_tril_expr || is_triu_mat || is_tril_mat)
     {
+    arma_debug_print("op_inv_gen_rcond: tri optimisation");
+    
     return auxlib::inv_tr_rcond(out, out_state.rcond, ((is_triu_expr || is_triu_mat) ? uword(0) : uword(1)));
     }
   
-  const bool try_sympd = arma_config::optimise_sym && ((auxlib::crippled_lapack(out)) ? false : sym_helper::guess_sympd(out));
-  
-  if(try_sympd)
+  if( (arma_config::optimise_sym) && ( is_sym_expr<T1>::eval(expr.get_ref()) || sym_helper::is_approx_sym(out, uword(100)) ) )
     {
-    arma_debug_print("op_inv_gen_rcond: attempting sympd optimisation");
+    arma_debug_print("op_inv_gen_rcond: symmetric/hermitian optimisation");
     
     out_state.is_sym = true;
     
-    Mat<eT> tmp = out;
-    
-    bool sympd_state = false;
-    
-    const bool status = auxlib::inv_sympd_rcond(tmp, sympd_state, out_state.rcond);
-    
-    if(status)  { out.steal_mem(tmp); return true; }
-    
-    if((status == false) && (sympd_state == true))  { return false; }
-    
-    arma_debug_print("op_inv_gen_rcond: sympd optimisation failed");
-    
-    // fallthrough if optimisation failed
+    return auxlib::inv_sym_rcond(out, out_state.rcond);
     }
   
   return auxlib::inv_rcond(out, out_state.rcond);
