@@ -1,12 +1,12 @@
 // SPDX-License-Identifier: Apache-2.0
 // 
-// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 Conrad Sanderson (https://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
-// http://www.apache.org/licenses/LICENSE-2.0
+// https://www.apache.org/licenses/LICENSE-2.0
 // 
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
@@ -25,7 +25,7 @@ template<typename obj_type>
 inline
 running_stat_vec<obj_type>::~running_stat_vec()
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   }
 
 
@@ -35,7 +35,7 @@ inline
 running_stat_vec<obj_type>::running_stat_vec(const bool in_calc_cov)
   : calc_cov(in_calc_cov)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   }
 
 
@@ -53,7 +53,7 @@ running_stat_vec<obj_type>::running_stat_vec(const running_stat_vec<obj_type>& i
   , min_val_norm(in_rsv.min_val_norm)
   , max_val_norm(in_rsv.max_val_norm)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   }
 
 
@@ -63,7 +63,7 @@ inline
 running_stat_vec<obj_type>&
 running_stat_vec<obj_type>::operator=(const running_stat_vec<obj_type>& in_rsv)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   access::rw(calc_cov) = in_rsv.calc_cov;
   
@@ -84,12 +84,11 @@ running_stat_vec<obj_type>::operator=(const running_stat_vec<obj_type>& in_rsv)
 //! update statistics to reflect new sample
 template<typename obj_type>
 template<typename T1>
-arma_hot
 inline
 void
 running_stat_vec<obj_type>::operator() (const Base<typename running_stat_vec<obj_type>::T, T1>& X)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(X.get_ref());
   const Mat<T>& sample = tmp.M;
@@ -99,9 +98,9 @@ running_stat_vec<obj_type>::operator() (const Base<typename running_stat_vec<obj
     return;
     }
   
-  if( sample.is_finite() == false )
+  if( sample.internal_has_nonfinite() )
     {
-    arma_debug_warn_level(3, "running_stat_vec: sample ignored as it has non-finite elements");
+    arma_warn(3, "running_stat_vec: non-finite sample ignored");
     return;
     }
   
@@ -112,12 +111,11 @@ running_stat_vec<obj_type>::operator() (const Base<typename running_stat_vec<obj
 
 template<typename obj_type>
 template<typename T1>
-arma_hot
 inline
 void
 running_stat_vec<obj_type>::operator() (const Base< std::complex<typename running_stat_vec<obj_type>::T>, T1>& X)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(X.get_ref());
   
@@ -128,9 +126,9 @@ running_stat_vec<obj_type>::operator() (const Base< std::complex<typename runnin
     return;
     }
   
-  if( sample.is_finite() == false )
+  if( sample.internal_has_nonfinite() )
     {
-    arma_debug_warn_level(3, "running_stat_vec: sample ignored as it has non-finite elements");
+    arma_warn(3, "running_stat_vec: non-finite sample ignored");
     return;
     }
   
@@ -145,7 +143,7 @@ inline
 void
 running_stat_vec<obj_type>::reset()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   counter.reset();
   
@@ -174,7 +172,7 @@ inline
 const typename running_stat_vec<obj_type>::return_type1&
 running_stat_vec<obj_type>::mean() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return r_mean;
   }
@@ -187,7 +185,7 @@ inline
 const typename running_stat_vec<obj_type>::return_type2&
 running_stat_vec<obj_type>::var(const uword norm_type)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const T N = counter.value();
   
@@ -223,7 +221,7 @@ inline
 typename running_stat_vec<obj_type>::return_type2
 running_stat_vec<obj_type>::stddev(const uword norm_type) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const T N = counter.value();
   
@@ -255,7 +253,7 @@ inline
 const Mat< typename running_stat_vec<obj_type>::eT >&
 running_stat_vec<obj_type>::cov(const uword norm_type)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(calc_cov)
     {
@@ -302,7 +300,7 @@ inline
 const typename running_stat_vec<obj_type>::return_type1&
 running_stat_vec<obj_type>::min() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return min_val;
   }
@@ -315,7 +313,7 @@ inline
 const typename running_stat_vec<obj_type>::return_type1&
 running_stat_vec<obj_type>::max() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return max_val;
   }
@@ -327,7 +325,7 @@ inline
 typename running_stat_vec<obj_type>::return_type1
 running_stat_vec<obj_type>::range() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return (max_val - min_val);
   }
@@ -340,7 +338,7 @@ inline
 typename running_stat_vec<obj_type>::T
 running_stat_vec<obj_type>::count() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return counter.value();
   }
@@ -362,7 +360,7 @@ running_stat_vec_aux::update_stats
   const typename arma_not_cx<typename running_stat_vec<obj_type>::eT>::result* junk
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   typedef typename running_stat_vec<obj_type>::eT eT;
@@ -372,7 +370,7 @@ running_stat_vec_aux::update_stats
   
   if(N > T(0))
     {
-    arma_debug_assert_same_size(x.r_mean, sample, "running_stat_vec(): dimensionality mismatch");
+    arma_conform_assert_same_size(x.r_mean, sample, "running_stat_vec(): dimensionality mismatch");
     
     const uword n_elem      = sample.n_elem;
     const eT*   sample_mem  = sample.memptr();
@@ -429,7 +427,7 @@ running_stat_vec_aux::update_stats
     }
   else
     {
-    arma_debug_check( (sample.is_vec() == false), "running_stat_vec(): given sample must be a vector" );
+    arma_conform_check( (sample.is_vec() == false), "running_stat_vec(): given sample must be a vector" );
     
     x.r_mean.set_size(sample.n_rows, sample.n_cols);
     
@@ -477,7 +475,7 @@ running_stat_vec_aux::update_stats
   const typename       arma_not_cx<typename running_stat_vec<obj_type>::eT>::result* junk
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   typedef typename running_stat_vec<obj_type>::eT eT;
@@ -498,7 +496,7 @@ running_stat_vec_aux::update_stats
   const typename arma_cx_only<typename running_stat_vec<obj_type>::eT>::result* junk
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   typedef typename running_stat_vec<obj_type>::eT eT;
@@ -519,7 +517,7 @@ running_stat_vec_aux::update_stats
   const typename arma_cx_only<typename running_stat_vec<obj_type>::eT>::result* junk
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   typedef typename running_stat_vec<obj_type>::eT eT;
@@ -529,7 +527,7 @@ running_stat_vec_aux::update_stats
   
   if(N > T(0))
     {
-    arma_debug_assert_same_size(x.r_mean, sample, "running_stat_vec(): dimensionality mismatch");
+    arma_conform_assert_same_size(x.r_mean, sample, "running_stat_vec(): dimensionality mismatch");
     
     const uword n_elem           = sample.n_elem;
     const eT*   sample_mem       = sample.memptr();
@@ -590,7 +588,7 @@ running_stat_vec_aux::update_stats
     }
   else
     {
-    arma_debug_check( (sample.is_vec() == false), "running_stat_vec(): given sample must be a vector" );
+    arma_conform_check( (sample.is_vec() == false), "running_stat_vec(): given sample must be a vector" );
     
     x.r_mean.set_size(sample.n_rows, sample.n_cols);
     
