@@ -1,12 +1,12 @@
 // SPDX-License-Identifier: Apache-2.0
 // 
-// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 Conrad Sanderson (https://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
-// http://www.apache.org/licenses/LICENSE-2.0
+// https://www.apache.org/licenses/LICENSE-2.0
 // 
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
@@ -24,7 +24,7 @@ template<typename eT, typename T1>
 inline
 subview_elem1<eT,T1>::~subview_elem1()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   }
 
 
@@ -34,7 +34,7 @@ subview_elem1<eT,T1>::subview_elem1(const Mat<eT>& in_m, const Base<uword,T1>& i
   : m(in_m)
   , a(in_a)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   }
 
 
@@ -46,7 +46,7 @@ subview_elem1<eT,T1>::subview_elem1(const Cube<eT>& in_q, const Base<uword,T1>&
   ,      m( fake_m )
   ,      a( in_a   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   }
 
 
@@ -57,7 +57,7 @@ inline
 void
 subview_elem1<eT,T1>::inplace_op(const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT>& m_local = const_cast< Mat<eT>& >(m);
   
@@ -67,11 +67,10 @@ subview_elem1<eT,T1>::inplace_op(const eT val)
   const unwrap_check_mixed<T1> tmp(a.get_ref(), m_local);
   const umat& aa = tmp.M;
   
-  arma_debug_check
-    (
-    ( (aa.is_vec() == false) && (aa.is_empty() == false) ),
-    "Mat::elem(): given object must be a vector"
-    );
+  if(resolves_to_vector<T1>::no)
+    {
+    arma_conform_check( ( (aa.is_vec() == false) && (aa.is_empty() == false) ), "Mat::elem(): given object must be a vector" );
+    }
   
   const uword* aa_mem    = aa.memptr();
   const uword  aa_n_elem = aa.n_elem;
@@ -82,7 +81,7 @@ subview_elem1<eT,T1>::inplace_op(const eT val)
     const uword ii = aa_mem[iq];
     const uword jj = aa_mem[jq];
     
-    arma_debug_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
+    arma_conform_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
     
     if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  val; m_mem[jj] =  val; }
     if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += val; m_mem[jj] += val; }
@@ -95,7 +94,7 @@ subview_elem1<eT,T1>::inplace_op(const eT val)
     {
     const uword ii = aa_mem[iq];
     
-    arma_debug_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" ); 
+    arma_conform_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" ); 
     
     if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  val; }
     if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += val; }
@@ -113,13 +112,13 @@ inline
 void
 subview_elem1<eT,T1>::inplace_op(const subview_elem1<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   subview_elem1<eT,T1>& s = *this;
   
   if(&(s.m) == &(x.m))
     {
-    arma_extra_debug_print("subview_elem1::inplace_op(): aliasing detected");
+    arma_debug_print("subview_elem1::inplace_op(): aliasing detected");
     
     const Mat<eT> tmp(x);
     
@@ -140,7 +139,7 @@ subview_elem1<eT,T1>::inplace_op(const subview_elem1<eT,T2>& x)
     const umat& s_aa = s_tmp.M;
     const umat& x_aa = x_tmp.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( ((s_aa.is_vec() == false) && (s_aa.is_empty() == false)) || ((x_aa.is_vec() == false) && (x_aa.is_empty() == false)) ),
       "Mat::elem(): given object must be a vector"
@@ -151,7 +150,7 @@ subview_elem1<eT,T1>::inplace_op(const subview_elem1<eT,T2>& x)
     
     const uword s_aa_n_elem = s_aa.n_elem;
     
-    arma_debug_check( (s_aa_n_elem != x_aa.n_elem), "Mat::elem(): size mismatch" );
+    arma_conform_check( (s_aa_n_elem != x_aa.n_elem), "Mat::elem(): size mismatch" );
     
     
           eT*   s_m_mem    = s_m_local.memptr();
@@ -169,7 +168,7 @@ subview_elem1<eT,T1>::inplace_op(const subview_elem1<eT,T2>& x)
       const uword x_ii = x_aa_mem[iq];
       const uword x_jj = x_aa_mem[jq];
       
-      arma_debug_check_bounds
+      arma_conform_check_bounds
         (
         (s_ii >= s_m_n_elem) || (s_jj >= s_m_n_elem) || (x_ii >= x_m_n_elem) || (x_jj >= x_m_n_elem),
         "Mat::elem(): index out of bounds"
@@ -187,7 +186,7 @@ subview_elem1<eT,T1>::inplace_op(const subview_elem1<eT,T2>& x)
       const uword s_ii = s_aa_mem[iq];
       const uword x_ii = x_aa_mem[iq];
       
-      arma_debug_check_bounds
+      arma_conform_check_bounds
         (
         ( (s_ii >= s_m_n_elem) || (x_ii >= x_m_n_elem) ),
         "Mat::elem(): index out of bounds"
@@ -210,7 +209,7 @@ inline
 void
 subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT>& m_local = const_cast< Mat<eT>& >(m);
   
@@ -220,22 +219,21 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
   const unwrap_check_mixed<T1> aa_tmp(a.get_ref(), m_local);
   const umat& aa = aa_tmp.M;
   
-  arma_debug_check
-    (
-    ( (aa.is_vec() == false) && (aa.is_empty() == false) ),
-    "Mat::elem(): given object must be a vector"
-    );
+  if(resolves_to_vector<T1>::no)
+    {
+    arma_conform_check( ( (aa.is_vec() == false) && (aa.is_empty() == false) ), "Mat::elem(): given object must be a vector" );
+    }
   
   const uword* aa_mem    = aa.memptr();
   const uword  aa_n_elem = aa.n_elem;
   
   const Proxy<T2> P(x.get_ref());
   
-  arma_debug_check( (aa_n_elem != P.get_n_elem()), "Mat::elem(): size mismatch" );
+  arma_conform_check( (aa_n_elem != P.get_n_elem()), "Mat::elem(): size mismatch" );
   
-  const bool is_alias = P.is_alias(m);
+  const bool have_alias = P.is_alias(m);
   
-  if( (is_alias == false) && (Proxy<T2>::use_at == false) )
+  if( (have_alias == false) && (Proxy<T2>::use_at == false) )
     {
     typename Proxy<T2>::ea_type X = P.get_ea();
     
@@ -245,7 +243,7 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
       const uword ii = aa_mem[iq];
       const uword jj = aa_mem[jq];
       
-      arma_debug_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
       
       if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  X[iq]; m_mem[jj]  = X[jq]; }
       if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += X[iq]; m_mem[jj] += X[jq]; }
@@ -258,7 +256,7 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
       {
       const uword ii = aa_mem[iq];
       
-      arma_debug_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
       
       if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  X[iq]; }
       if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += X[iq]; }
@@ -269,9 +267,9 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
     }
   else
     {
-    arma_extra_debug_print("subview_elem1::inplace_op(): aliasing or use_at detected");
+    arma_debug_print("subview_elem1::inplace_op(): aliasing or use_at detected");
     
-    const unwrap_check<typename Proxy<T2>::stored_type> tmp(P.Q, is_alias);
+    const unwrap_check<typename Proxy<T2>::stored_type> tmp(P.Q, have_alias);
     const Mat<eT>& M = tmp.M;
     
     const eT* X = M.memptr();
@@ -282,7 +280,7 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
       const uword ii = aa_mem[iq];
       const uword jj = aa_mem[jq];
       
-      arma_debug_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
       
       if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  X[iq]; m_mem[jj]  = X[jq]; }
       if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += X[iq]; m_mem[jj] += X[jq]; }
@@ -295,7 +293,7 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
       {
       const uword ii = aa_mem[iq];
       
-      arma_debug_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
       
       if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  X[iq]; }
       if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += X[iq]; }
@@ -348,7 +346,7 @@ inline
 void
 subview_elem1<eT,T1>::replace(const eT old_val, const eT new_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT>& m_local = const_cast< Mat<eT>& >(m);
   
@@ -358,11 +356,10 @@ subview_elem1<eT,T1>::replace(const eT old_val, const eT new_val)
   const unwrap_check_mixed<T1> tmp(a.get_ref(), m_local);
   const umat& aa = tmp.M;
   
-  arma_debug_check
-    (
-    ( (aa.is_vec() == false) && (aa.is_empty() == false) ),
-    "Mat::elem(): given object must be a vector"
-    );
+  if(resolves_to_vector<T1>::no)
+    {
+    arma_conform_check( ( (aa.is_vec() == false) && (aa.is_empty() == false) ), "Mat::elem(): given object must be a vector" );
+    }
   
   const uword* aa_mem    = aa.memptr();
   const uword  aa_n_elem = aa.n_elem;
@@ -373,7 +370,7 @@ subview_elem1<eT,T1>::replace(const eT old_val, const eT new_val)
       {
       const uword ii = aa_mem[iq];
       
-      arma_debug_check_bounds( (ii >= m_n_elem), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (ii >= m_n_elem), "Mat::elem(): index out of bounds" );
       
       eT& val = m_mem[ii];
       
@@ -386,7 +383,7 @@ subview_elem1<eT,T1>::replace(const eT old_val, const eT new_val)
       {
       const uword ii = aa_mem[iq];
       
-      arma_debug_check_bounds( (ii >= m_n_elem), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (ii >= m_n_elem), "Mat::elem(): index out of bounds" );
       
       eT& val = m_mem[ii];
       
@@ -402,7 +399,7 @@ inline
 void
 subview_elem1<eT,T1>::clean(const pod_type threshold)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT> tmp(*this);
   
@@ -418,7 +415,7 @@ inline
 void
 subview_elem1<eT,T1>::clamp(const eT min_val, const eT max_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT> tmp(*this);
   
@@ -434,7 +431,7 @@ inline
 void
 subview_elem1<eT,T1>::fill(const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(val);
   }
@@ -446,7 +443,7 @@ inline
 void
 subview_elem1<eT,T1>::zeros()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(eT(0));
   }
@@ -458,7 +455,7 @@ inline
 void
 subview_elem1<eT,T1>::ones()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(eT(1));
   }
@@ -470,47 +467,37 @@ inline
 void
 subview_elem1<eT,T1>::randu()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT>& m_local = const_cast< Mat<eT>& >(m);
   
         eT*   m_mem    = m_local.memptr();
   const uword m_n_elem = m_local.n_elem;
   
-  const unwrap_check_mixed<T1> tmp(a.get_ref(), m_local);
-  const umat& aa = tmp.M;
+  const unwrap_check_mixed<T1> U(a.get_ref(), m_local);
+  const umat& aa = U.M;
   
-  arma_debug_check
-    (
-    ( (aa.is_vec() == false) && (aa.is_empty() == false) ),
-    "Mat::elem(): given object must be a vector"
-    );
+  if(resolves_to_vector<T1>::no)
+    {
+    arma_conform_check( ( (aa.is_vec() == false) && (aa.is_empty() == false) ), "Mat::elem(): given object must be a vector" );
+    }
   
   const uword* aa_mem    = aa.memptr();
   const uword  aa_n_elem = aa.n_elem;
   
-  uword iq,jq;
-  for(iq=0, jq=1; jq < aa_n_elem; iq+=2, jq+=2)
-    {
-    const uword ii = aa_mem[iq];
-    const uword jj = aa_mem[jq];
-    
-    arma_debug_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
-    
-    const eT val1 = eT(arma_rng::randu<eT>());
-    const eT val2 = eT(arma_rng::randu<eT>());
-    
-    m_mem[ii] = val1;
-    m_mem[jj] = val2;
-    }
+  podarray<eT> tmp(aa_n_elem);
   
-  if(iq < aa_n_elem)
+  eT* tmp_mem = tmp.memptr();
+  
+  arma_rng::randu<eT>::fill(tmp_mem, aa_n_elem);
+  
+  for(uword iq=0; iq < aa_n_elem; ++iq)
     {
     const uword ii = aa_mem[iq];
     
-    arma_debug_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" ); 
+    arma_conform_check_bounds( (ii >= m_n_elem), "Mat::elem(): index out of bounds" );
     
-    m_mem[ii] = eT(arma_rng::randu<eT>());
+    m_mem[ii] = tmp_mem[iq];
     }
   }
 
@@ -521,43 +508,37 @@ inline
 void
 subview_elem1<eT,T1>::randn()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT>& m_local = const_cast< Mat<eT>& >(m);
   
         eT*   m_mem    = m_local.memptr();
   const uword m_n_elem = m_local.n_elem;
   
-  const unwrap_check_mixed<T1> tmp(a.get_ref(), m_local);
-  const umat& aa = tmp.M;
+  const unwrap_check_mixed<T1> U(a.get_ref(), m_local);
+  const umat& aa = U.M;
   
-  arma_debug_check
-    (
-    ( (aa.is_vec() == false) && (aa.is_empty() == false) ),
-    "Mat::elem(): given object must be a vector"
-    );
+  if(resolves_to_vector<T1>::no)
+    {
+    arma_conform_check( ( (aa.is_vec() == false) && (aa.is_empty() == false) ), "Mat::elem(): given object must be a vector" );
+    }
   
   const uword* aa_mem    = aa.memptr();
   const uword  aa_n_elem = aa.n_elem;
   
-  uword iq,jq;
-  for(iq=0, jq=1; jq < aa_n_elem; iq+=2, jq+=2)
-    {
-    const uword ii = aa_mem[iq];
-    const uword jj = aa_mem[jq];
-    
-    arma_debug_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
-    
-    arma_rng::randn<eT>::dual_val( m_mem[ii], m_mem[jj] );
-    }
+  podarray<eT> tmp(aa_n_elem);
   
-  if(iq < aa_n_elem)
+  eT* tmp_mem = tmp.memptr();
+  
+  arma_rng::randn<eT>::fill(tmp_mem, aa_n_elem);
+  
+  for(uword iq=0; iq < aa_n_elem; ++iq)
     {
     const uword ii = aa_mem[iq];
     
-    arma_debug_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" ); 
+    arma_conform_check_bounds( (ii >= m_n_elem), "Mat::elem(): index out of bounds" );
     
-    m_mem[ii] = eT(arma_rng::randn<eT>());
+    m_mem[ii] = tmp_mem[iq];
     }
   }
 
@@ -568,7 +549,7 @@ inline
 void
 subview_elem1<eT,T1>::operator+= (const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_plus>(val);
   }
@@ -580,7 +561,7 @@ inline
 void
 subview_elem1<eT,T1>::operator-= (const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_minus>(val);
   }
@@ -592,7 +573,7 @@ inline
 void
 subview_elem1<eT,T1>::operator*= (const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_schur>(val);
   }
@@ -604,7 +585,7 @@ inline
 void
 subview_elem1<eT,T1>::operator/= (const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_div>(val);
   }
@@ -622,7 +603,7 @@ inline
 void
 subview_elem1<eT,T1>::operator_equ(const subview_elem1<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(x);
   }
@@ -636,7 +617,7 @@ inline
 void
 subview_elem1<eT,T1>::operator= (const subview_elem1<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).operator_equ(x);
   }
@@ -649,7 +630,7 @@ inline
 void
 subview_elem1<eT,T1>::operator= (const subview_elem1<eT,T1>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).operator_equ(x);
   }
@@ -662,7 +643,7 @@ inline
 void
 subview_elem1<eT,T1>::operator+= (const subview_elem1<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_plus>(x);
   }
@@ -675,7 +656,7 @@ inline
 void
 subview_elem1<eT,T1>::operator-= (const subview_elem1<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_minus>(x);
   }
@@ -688,7 +669,7 @@ inline
 void
 subview_elem1<eT,T1>::operator%= (const subview_elem1<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_schur>(x);
   }
@@ -701,7 +682,7 @@ inline
 void
 subview_elem1<eT,T1>::operator/= (const subview_elem1<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_div>(x);
   }
@@ -714,7 +695,7 @@ inline
 void
 subview_elem1<eT,T1>::operator= (const Base<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(x);
   }
@@ -727,7 +708,7 @@ inline
 void
 subview_elem1<eT,T1>::operator+= (const Base<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_plus>(x);
   }
@@ -740,7 +721,7 @@ inline
 void
 subview_elem1<eT,T1>::operator-= (const Base<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_minus>(x);
   }
@@ -753,7 +734,7 @@ inline
 void
 subview_elem1<eT,T1>::operator%= (const Base<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_schur>(x);
   }
@@ -766,7 +747,7 @@ inline
 void
 subview_elem1<eT,T1>::operator/= (const Base<eT,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_div>(x);
   }
@@ -783,16 +764,15 @@ inline
 void
 subview_elem1<eT,T1>::extract(Mat<eT>& actual_out, const subview_elem1<eT,T1>& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_check_mixed<T1> tmp1(in.a.get_ref(), actual_out);
   const umat& aa = tmp1.M;
   
-  arma_debug_check
-    (
-    ( (aa.is_vec() == false) && (aa.is_empty() == false) ),
-    "Mat::elem(): given object must be a vector"
-    );
+  if(resolves_to_vector<T1>::no)
+    {
+    arma_conform_check( ( (aa.is_vec() == false) && (aa.is_empty() == false) ), "Mat::elem(): given object must be a vector" );
+    }
   
   const uword* aa_mem    = aa.memptr();
   const uword  aa_n_elem = aa.n_elem;
@@ -804,7 +784,7 @@ subview_elem1<eT,T1>::extract(Mat<eT>& actual_out, const subview_elem1<eT,T1>& i
   
   const bool alias = (&actual_out == &m_local);
   
-  if(alias)  { arma_extra_debug_print("subview_elem1::extract(): aliasing detected"); }
+  if(alias)  { arma_debug_print("subview_elem1::extract(): aliasing detected"); }
   
   Mat<eT>* tmp_out = alias ? new Mat<eT>() : nullptr;
   Mat<eT>& out     = alias ? *tmp_out      : actual_out;
@@ -819,7 +799,7 @@ subview_elem1<eT,T1>::extract(Mat<eT>& actual_out, const subview_elem1<eT,T1>& i
     const uword ii = aa_mem[i];
     const uword jj = aa_mem[j];
     
-    arma_debug_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
+    arma_conform_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
     
     out_mem[i] = m_mem[ii];
     out_mem[j] = m_mem[jj];
@@ -829,7 +809,7 @@ subview_elem1<eT,T1>::extract(Mat<eT>& actual_out, const subview_elem1<eT,T1>& i
     {
     const uword ii = aa_mem[i];
     
-    arma_debug_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
+    arma_conform_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
     
     out_mem[i] = m_mem[ii];
     }
@@ -849,16 +829,15 @@ inline
 void
 subview_elem1<eT,T1>::mat_inplace_op(Mat<eT>& out, const subview_elem1& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1> tmp1(in.a.get_ref());
   const umat& aa = tmp1.M;
   
-  arma_debug_check
-    (
-    ( (aa.is_vec() == false) && (aa.is_empty() == false) ),
-    "Mat::elem(): given object must be a vector"
-    );
+  if(resolves_to_vector<T1>::no)
+    {
+    arma_conform_check( ( (aa.is_vec() == false) && (aa.is_empty() == false) ), "Mat::elem(): given object must be a vector" );
+    }
   
   const uword* aa_mem    = aa.memptr();
   const uword  aa_n_elem = aa.n_elem;
@@ -869,7 +848,7 @@ subview_elem1<eT,T1>::mat_inplace_op(Mat<eT>& out, const subview_elem1& in)
   const eT*   m_mem    = m_local.memptr();
   const uword m_n_elem = m_local.n_elem;
   
-  arma_debug_check( (out.n_elem != aa_n_elem), "Mat::elem(): size mismatch" );
+  arma_conform_check( (out.n_elem != aa_n_elem), "Mat::elem(): size mismatch" );
   
   eT* out_mem = out.memptr();
   
@@ -879,7 +858,7 @@ subview_elem1<eT,T1>::mat_inplace_op(Mat<eT>& out, const subview_elem1& in)
     const uword ii = aa_mem[i];
     const uword jj = aa_mem[j];
     
-    arma_debug_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
+    arma_conform_check_bounds( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
     
     if(is_same_type<op_type, op_internal_plus >::yes) { out_mem[i] += m_mem[ii]; out_mem[j] += m_mem[jj]; }
     if(is_same_type<op_type, op_internal_minus>::yes) { out_mem[i] -= m_mem[ii]; out_mem[j] -= m_mem[jj]; }
@@ -891,7 +870,7 @@ subview_elem1<eT,T1>::mat_inplace_op(Mat<eT>& out, const subview_elem1& in)
     {
     const uword ii = aa_mem[i];
     
-    arma_debug_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
+    arma_conform_check_bounds( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
     
     if(is_same_type<op_type, op_internal_plus >::yes) { out_mem[i] += m_mem[ii]; }
     if(is_same_type<op_type, op_internal_minus>::yes) { out_mem[i] -= m_mem[ii]; }
@@ -907,7 +886,7 @@ inline
 void
 subview_elem1<eT,T1>::plus_inplace(Mat<eT>& out, const subview_elem1& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   mat_inplace_op<op_internal_plus>(out, in);
   }
@@ -919,7 +898,7 @@ inline
 void
 subview_elem1<eT,T1>::minus_inplace(Mat<eT>& out, const subview_elem1& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   mat_inplace_op<op_internal_minus>(out, in);
   }
@@ -931,7 +910,7 @@ inline
 void
 subview_elem1<eT,T1>::schur_inplace(Mat<eT>& out, const subview_elem1& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   mat_inplace_op<op_internal_schur>(out, in);
   }
@@ -943,11 +922,24 @@ inline
 void
 subview_elem1<eT,T1>::div_inplace(Mat<eT>& out, const subview_elem1& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   mat_inplace_op<op_internal_div>(out, in);
   }
 
 
 
+template<typename eT, typename T1>
+template<typename eT2>
+inline
+bool
+subview_elem1<eT,T1>::is_alias(const Mat<eT2>& X) const
+  {
+  arma_debug_sigprint();
+  
+  return (m.is_alias(X) || a.get_ref().is_alias(X));
+  }
+
+
+
 //! @}
