@@ -1,12 +1,12 @@
 // SPDX-License-Identifier: Apache-2.0
 // 
-// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 Conrad Sanderson (https://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
-// http://www.apache.org/licenses/LICENSE-2.0
+// https://www.apache.org/licenses/LICENSE-2.0
 // 
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
@@ -35,9 +35,8 @@
   #endif
 #endif
 
-// NOTE:
-// "char" is not guaranteed to be the same as "signed char" 
-// https://en.wikipedia.org/wiki/C_data_types
+// NOTE: "char" can be either "signed char" or "unsigned char"
+// NOTE: https://en.wikipedia.org/wiki/C_data_types
 
 
 #if   USHRT_MAX >= 0xffff
@@ -108,12 +107,9 @@ typedef void* void_ptr;
 //
 
 
-#if   defined(ARMA_BLAS_LONG_LONG)
+#if defined(ARMA_BLAS_64BIT_INT)
   typedef long long blas_int;
   #define ARMA_MAX_BLAS_INT 0x7fffffffffffffffULL
-#elif defined(ARMA_BLAS_LONG)
-  typedef long      blas_int;
-  #define ARMA_MAX_BLAS_INT 0x7fffffffffffffffUL
 #else
   typedef int       blas_int;
   #define ARMA_MAX_BLAS_INT 0x7fffffffU
@@ -137,6 +133,67 @@ typedef void* void_ptr;
 //
 
 
+#undef ARMA_HAVE_FP16
+#undef ARMA_GOOD_FP16
+
+#if !defined(ARMA_DONT_USE_FP16)
+#if defined(ARMA_HAVE_CXX23)
+  
+  #if defined(__aarch64__)
+    #if defined(__ARM_FEATURE_FP16_SCALAR_ARITHMETIC)
+      // need scalar intrinsics for native FP16 support
+      #define ARMA_GOOD_FP16
+    #endif
+  #elif defined(__x86_64__) || defined(__i386__)
+    #if defined(__F16C__) || defined(__AVX512FP16__)
+      // NOTE: AVX512-FP16 extensions are preferred for native FP16 support
+      #define ARMA_GOOD_FP16
+    #endif
+  #endif
+  
+  #if defined(__STDCPP_FLOAT16_T__) && (__STDCPP_FLOAT16_T__ == 1)
+    
+    #if defined(ARMA_FORCE_USE_FP16) || defined(ARMA_GOOD_FP16)
+      #define ARMA_HAVE_FP16
+      typedef              std::float16_t     fp16;
+      typedef std::complex<std::float16_t> cx_fp16;
+    #endif
+    
+    #if defined(ARMA_FORCE_USE_FP16) && !defined(ARMA_GOOD_FP16)
+      #if defined(__GNUG__) || defined(__clang__)
+        #pragma message ("WARNING: hardware support for fp16 not detected; emulated fp16 can be slow; try adding -march=native to compiler flags")
+      #else
+        #pragma message ("WARNING: hardware support for fp16 not detected; emulated fp16 can be slow")
+      #endif
+    #endif
+    
+  #else
+    
+    #if defined(ARMA_FORCE_USE_FP16)
+      #if defined(__GNUG__) || defined(__clang__)
+        #pragma message ("WARNING: C++ support for fp16 not detected; try adding -std=c++23 to compiler flags")
+      #else
+        #pragma message ("WARNING: C++ support for fp16 not detected")
+      #endif
+    #endif
+    
+    #undef ARMA_GOOD_FP16
+    
+  #endif
+  
+#else
+  
+  #if defined(ARMA_FORCE_USE_FP16)
+    #pragma message ("WARNING: C++23 required for fp16 support")
+  #endif
+  
+#endif
+#endif
+
+
+//
+
+
 // NOTE: blas_len is the fortran type for "hidden" arguments that specify the length of character arguments;
 // NOTE: it varies across compilers, compiler versions and systems (eg. 32 bit vs 64 bit);
 // NOTE: the default setting of "size_t" is an educated guess.
@@ -158,16 +215,7 @@ typedef void* void_ptr;
 // TODO: other compilers: http://fortranwiki.org/fortran/show/Compilers
 
 #if !defined(ARMA_FORTRAN_CHARLEN_TYPE)
-  #if defined(__GNUC__) && !defined(__clang__)
-    #if (__GNUC__ <= 7)
-      #define ARMA_FORTRAN_CHARLEN_TYPE int
-    #else
-      #define ARMA_FORTRAN_CHARLEN_TYPE size_t
-    #endif
-  #else
-    // TODO: determine the type for other compilers
-    #define ARMA_FORTRAN_CHARLEN_TYPE size_t
-  #endif
+  #define ARMA_FORTRAN_CHARLEN_TYPE size_t
 #endif
 
 typedef ARMA_FORTRAN_CHARLEN_TYPE blas_len;
