@@ -18,11 +18,12 @@
 
 #include <armadillo>
 #include "catch.hpp"
+#include "utils.hpp"
 
 using namespace arma;
 
 
-TEST_CASE("fn_conj_1")
+TEST_CASE("fn_conj_1", "[conj]")
   {
   vec re =   linspace<vec>(1,5,6);
   vec im = 2*linspace<vec>(1,5,6);
@@ -36,7 +37,7 @@ TEST_CASE("fn_conj_1")
 
 
 
-TEST_CASE("fn_conj2")
+TEST_CASE("fn_conj2", "[conj]")
   {
   cx_mat A = randu<cx_mat>(5,6);
   
@@ -45,3 +46,16 @@ TEST_CASE("fn_conj2")
   REQUIRE( all(vectorise(real(B) ==  real(A))) == true );
   REQUIRE( all(vectorise(imag(B) == -imag(A))) == true );
   }
+
+
+
+TEMPLATE_TEST_CASE("fn_conj_fp_randu", "[conj]", TEST_CX_FLOAT_TYPES)
+  {
+  typedef TestType eT; // std::complex<something>
+
+  Mat<eT> A = randu<Mat<eT>>(50, 50);
+  Mat<eT> B = conj(A);
+
+  REQUIRE( all(vectorise(real(B) ==  real(A))) == true );
+  REQUIRE( all(vectorise(imag(B) == -imag(A))) == true );
+  }
