@@ -18,11 +18,12 @@
 
 #include <armadillo>
 #include "catch.hpp"
+#include "utils.hpp"
 
 using namespace arma;
 
 
-TEST_CASE("fn_find_unique_1")
+TEST_CASE("fn_find_unique_1", "[find]")
   {
   mat A = 
     {
@@ -55,7 +56,7 @@ TEST_CASE("fn_find_unique_1")
 
 
 
-TEST_CASE("fn_find_unique_2")
+TEST_CASE("fn_find_unique_2", "[find]")
   {
   cx_mat A = 
     {
@@ -98,3 +99,16 @@ TEST_CASE("fn_find_unique_2")
   
   // REQUIRE_THROWS(  );
   }
+
+
+
+TEMPLATE_TEST_CASE("fn_find_unique_fp", "[find]", TEST_FLOAT_TYPES)
+  {
+  typedef TestType eT;
+
+  Col<eT> X({ eT(0), eT(1), eT(1), eT(2), eT(1), eT(2) });
+
+  uvec r = find_unique(X);
+
+  REQUIRE( all( r == uvec({ 0, 1, 3 }) ) );
+  }
