@@ -18,10 +18,11 @@
 #include <armadillo>
 
 #include "catch.hpp"
+#include "utils.hpp"
 
 using namespace arma;
 
-TEST_CASE("fn_min_subview_test")
+TEST_CASE("fn_min_subview_test", "[min]")
   {
   // We will assume subview.at() works and returns points within the bounds of
   // the matrix, so we just have to ensure the results are the same as
@@ -54,7 +55,7 @@ TEST_CASE("fn_min_subview_test")
 
 
 
-TEST_CASE("fn_min_subview_col_test")
+TEST_CASE("fn_min_subview_col_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -80,7 +81,7 @@ TEST_CASE("fn_min_subview_col_test")
 
 
 
-TEST_CASE("fn_min_subview_row_test")
+TEST_CASE("fn_min_subview_row_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -106,7 +107,7 @@ TEST_CASE("fn_min_subview_row_test")
 
 
 
-// TEST_CASE("fn_min_incomplete_subview_test")
+// TEST_CASE("fn_min_incomplete_subview_test", "[min]")
 //   {
 //   for (size_t r = 50; r < 150; ++r)
 //     {
@@ -147,7 +148,7 @@ TEST_CASE("fn_min_subview_row_test")
 
 
 
-TEST_CASE("fn_min_incomplete_subview_col_test")
+TEST_CASE("fn_min_incomplete_subview_col_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -176,7 +177,7 @@ TEST_CASE("fn_min_incomplete_subview_col_test")
 
 
 
-TEST_CASE("fn_min_cx_subview_row_test")
+TEST_CASE("fn_min_cx_subview_row_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -205,7 +206,7 @@ TEST_CASE("fn_min_cx_subview_row_test")
 
 
 
-// TEST_CASE("fn_min_cx_incomplete_subview_test")
+// TEST_CASE("fn_min_cx_incomplete_subview_test", "[min]")
 //   {
 //   for (size_t r = 50; r < 150; ++r)
 //     {
@@ -249,7 +250,7 @@ TEST_CASE("fn_min_cx_subview_row_test")
 
 
 
-TEST_CASE("fn_min_cx_incomplete_subview_col_test")
+TEST_CASE("fn_min_cx_incomplete_subview_col_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -281,7 +282,7 @@ TEST_CASE("fn_min_cx_incomplete_subview_col_test")
 
 
 
-TEST_CASE("fn_min_cx_incomplete_subview_row_test")
+TEST_CASE("fn_min_cx_incomplete_subview_row_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -313,7 +314,7 @@ TEST_CASE("fn_min_cx_incomplete_subview_row_test")
 
 
 
-TEST_CASE("fn_min_weird_operation")
+TEST_CASE("fn_min_weird_operation", "[min]")
   {
   mat a(10, 10, fill::randn);
   mat b(25, 10, fill::randn);
@@ -333,7 +334,7 @@ TEST_CASE("fn_min_weird_operation")
 
 
 
-TEST_CASE("fn_min_weird_sparse_operation")
+TEST_CASE("fn_min_weird_sparse_operation", "[min]")
   {
   sp_mat a; a.sprandn(10, 10, 0.3);
   sp_mat b; b.sprandn(25, 10, 0.3);
@@ -353,7 +354,7 @@ TEST_CASE("fn_min_weird_sparse_operation")
 
 
 
-TEST_CASE("fn_min_sp_subview_test")
+TEST_CASE("fn_min_sp_subview_test", "[min]")
   {
   // We will assume subview.at() works and returns points within the bounds of
   // the matrix, so we just have to ensure the results are the same as
@@ -389,7 +390,7 @@ TEST_CASE("fn_min_sp_subview_test")
 
 
 
-TEST_CASE("fn_min_spsubview_col_test")
+TEST_CASE("fn_min_spsubview_col_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -418,7 +419,7 @@ TEST_CASE("fn_min_spsubview_col_test")
 
 
 
-TEST_CASE("fn_min_spsubview_row_min_test")
+TEST_CASE("fn_min_spsubview_row_min_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -447,7 +448,7 @@ TEST_CASE("fn_min_spsubview_row_min_test")
 
 
 
-// TEST_CASE("fn_min_spincompletesubview_min_test")
+// TEST_CASE("fn_min_spincompletesubview_min_test", "[min]")
 //   {
 //   for (size_t r = 50; r < 150; ++r)
 //     {
@@ -489,7 +490,7 @@ TEST_CASE("fn_min_spsubview_row_min_test")
 
 
 
-TEST_CASE("fn_min_spincompletesubview_col_min_test")
+TEST_CASE("fn_min_spincompletesubview_col_min_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -518,7 +519,7 @@ TEST_CASE("fn_min_spincompletesubview_col_min_test")
 
 
 
-TEST_CASE("fn_min_spincompletesubview_row_min_test")
+TEST_CASE("fn_min_spincompletesubview_row_min_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -547,7 +548,7 @@ TEST_CASE("fn_min_spincompletesubview_row_min_test")
 
 
 
-TEST_CASE("fn_min_sp_cx_subview_min_test")
+TEST_CASE("fn_min_sp_cx_subview_min_test", "[min]")
   {
   // We will assume subview.at() works and returns points within the bounds of
   // the matrix, so we just have to ensure the results are the same as
@@ -587,7 +588,7 @@ TEST_CASE("fn_min_sp_cx_subview_min_test")
 
 
 
-TEST_CASE("fn_min_sp_cx_subview_col_min_test")
+TEST_CASE("fn_min_sp_cx_subview_col_min_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -619,7 +620,7 @@ TEST_CASE("fn_min_sp_cx_subview_col_min_test")
 
 
 
-TEST_CASE("fn_min_sp_cx_subview_row_min_test")
+TEST_CASE("fn_min_sp_cx_subview_row_min_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -651,7 +652,7 @@ TEST_CASE("fn_min_sp_cx_subview_row_min_test")
 
 
 
-// TEST_CASE("fn_min_sp_cx_incomplete_subview_min_test")
+// TEST_CASE("fn_min_sp_cx_incomplete_subview_min_test", "[min]")
 //   {
 //   for (size_t r = 50; r < 150; ++r)
 //     {
@@ -696,7 +697,7 @@ TEST_CASE("fn_min_sp_cx_subview_row_min_test")
 
 
 
-TEST_CASE("fn_min_sp_cx_incomplete_subview_col_min_test")
+TEST_CASE("fn_min_sp_cx_incomplete_subview_col_min_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -728,7 +729,7 @@ TEST_CASE("fn_min_sp_cx_incomplete_subview_col_min_test")
 
 
 
-TEST_CASE("fn_min_sp_cx_incomplete_subview_row_min_test")
+TEST_CASE("fn_min_sp_cx_incomplete_subview_row_min_test", "[min]")
   {
   for (size_t r = 10; r < 50; ++r)
     {
@@ -757,3 +758,81 @@ TEST_CASE("fn_min_sp_cx_incomplete_subview_row_min_test")
       }
     }
   }
+
+
+
+TEMPLATE_TEST_CASE("fn_min_unary_fp_reference", "[min]", TEST_FLOAT_TYPES)
+  {
+  typedef TestType eT;
+
+  constexpr eT margin = is_blas_real<eT>::value ? eT(0.001) : eT(0.1);
+
+  Mat<eT> X(10, 10, fill::randn);
+  mat X_ref = conv_to<mat>::from(X);
+
+  eT min_val = X.min();
+  uword min_val_index = X.index_min();
+
+  double min_val_ref = X_ref.min();
+  uword min_val_index_ref = X_ref.index_min();
+
+  REQUIRE( min_val == Approx(eT(min_val_ref)).margin(margin) );
+  REQUIRE( min_val_index == min_val_index_ref );
+
+  min_val = min(vectorise(X));
+  min_val_index = index_min(vectorise(X));
+  min_val_ref = min(vectorise(X_ref));
+  min_val_index_ref = index_min(vectorise(X_ref));
+
+  REQUIRE( min_val == Approx(eT(min_val_ref)).margin(margin) );
+  REQUIRE( min_val_index == min_val_index_ref );
+
+  min_val = X.submat(1, 1, 6, 6).min();
+  min_val_index = X.submat(1, 1, 6, 6).index_min();
+  min_val_ref = X_ref.submat(1, 1, 6, 6).min();
+  min_val_index_ref = X_ref.submat(1, 1, 6, 6).index_min();
+
+  REQUIRE( min_val == Approx(eT(min_val_ref)).margin(margin) );
+  REQUIRE( min_val_index == min_val_index_ref );
+
+  min_val = min(vectorise(X.submat(1, 1, 6, 6)));
+  min_val_index = index_min(vectorise(X.submat(1, 1, 6, 6)));
+  min_val_ref = min(vectorise(X_ref.submat(1, 1, 6, 6)));
+  min_val_index_ref = index_min(vectorise(X_ref.submat(1, 1, 6, 6)));
+
+  REQUIRE( min_val == Approx(eT(min_val_ref)).margin(margin) );
+  REQUIRE( min_val_index == min_val_index_ref );
+  }
+
+
+
+TEMPLATE_TEST_CASE("fn_min_binary_fp_reference", "[min]", TEST_FLOAT_TYPES)
+  {
+  typedef TestType eT;
+
+  Mat<eT> X(10, 10, fill::randn);
+  Mat<eT> Y(10, 10, fill::randn);
+
+  Mat<eT> Z = min(X, Y);
+
+  REQUIRE( Z.n_rows == X.n_rows );
+  REQUIRE( Z.n_cols == X.n_cols );
+
+  for (uword i = 0; i < Z.n_elem; ++i)
+    {
+    REQUIRE( Z[i] == Approx(std::min(X[i], Y[i])) );
+    }
+
+  Z = min(X.submat(1, 1, 6, 6), Y.submat(1, 1, 6, 6));
+
+  REQUIRE( Z.n_rows == 6 );
+  REQUIRE( Z.n_cols == 6 );
+
+  for (uword c = 0; c < Z.n_cols; ++c)
+    {
+    for (uword r = 0; r < Z.n_rows; ++r)
+      {
+      REQUIRE( Z(r, c) == Approx(std::min(X(r + 1, c + 1), Y(r + 1, c + 1))) );
+      }
+    }
+  }
